Struct embedded_hal_sync_pins::pins::PushPullPin[][src]

pub struct PushPullPin { /* fields omitted */ }
A mutable output pin that can be safely shared between threads.

This pin implements embedded_hal::OutputPin and can be used to share an AtomicPinState with an embedded_hal implementation.

It also implements embedded_hal::InputPin, so it is possible to also read the internal state.

Examples

use embedded_hal_sync_pins::pins::{AtomicPinState, PushPullPin, PinState};
use embedded_hal::digital::blocking::{InputPin as HalInputPin, OutputPin};
use std::sync::Arc;

let state = Arc::new(AtomicPinState::new());
let mut pin = PushPullPin::new(state.clone());
pin.set_low().unwrap();
assert_eq!(Ok(true), pin.is_low());
pin.set_high().unwrap();
assert_eq!(Ok(true), pin.is_high());

Implementations